\_develop: Represents system packages recommended for development
=================================================================

Description
-----------

Script package representing a list of system packages recommended for developers.
